#check_install.py: checks that everything is ok for running the packages
#needed in 21M.385

import sys
import importlib
import platform
import os.path
import time

sys.path.append('check')

PY_TGT_VERSION = (2,7,12)

def check(cond, txt) :
    if cond:
        print txt, '[YES]'
    else:
        print txt, '[FAILURE]'
        sys.exit()

def check_module(mod, test_func=None, setup_func=None) :
    print 'checking', mod
    if setup_func:
        setup_func()
    try:
        m =  importlib.import_module(mod)
        if test_func:
            test_func(m)
        print m, '[YES]'
    except Exception, e:
        print e
        print "Problem with module", mod , '[FAILURE]'
        sys.exit()

def pyaudio_check(m) :
    found_asio = False
    pa = m.PyAudio()
    for i in range(pa.get_host_api_count()):
        api = pa.get_host_api_info_by_index(i)
        if api['type'] == m.paASIO:
            found_asio = True

    if platform.system() == 'Windows':
        check(found_asio, "Windows ASIO drivers available")


def fluid_check(m):
    if m.Synth().sfload('check/example.sf2') == -1:
        raise Exception('Error with fluidsynth.sfload()')

def leap_setup():
    if platform.system() == 'Windows':
        sys.path.append(os.path.join('check', 'x64'))
    elif platform.system() == 'Darwin':
        sys.path.append(os.path.join('check', 'osx'))

def leap_check(m):
    lc = m.Controller()
    time.sleep(1)
    print 'service connected:', lc.is_service_connected()



check(sys.version_info[:2] == PY_TGT_VERSION[:2], "Python Version == %d.%d" % PY_TGT_VERSION[:2])
check(sys.version_info[2] >= PY_TGT_VERSION[2], "Python Version >= %d.%d.%d" % PY_TGT_VERSION)

if platform.system() == 'Windows':
    check(platform.architecture()[0] == '64bit', "Python Windows is 64bit")
elif platform.system() == 'Darwin':
    check(platform.architecture()[0] == '64bit', "Python Mac is 64bit")

check_module('numpy', lambda m: m.zeros(4))
check_module('pyaudio', pyaudio_check)
check_module('fluidsynth', fluid_check)
check_module('OSC')
check_module('rtmidi_python')
check_module('kivy')
check_module('Leap', setup_func=leap_setup, test_func=leap_check)

print '\nEverything looks good'
