#!/bin/bash

PYTHON_TGT_VER="2.7.13"
PYTHON_TGT_LOC="/usr/local/bin/python"


function brew_install {
    printf "brew install $1\n"
    if brew ls --versions $1 > /dev/null; then
        brew upgrade $1
    else
        brew install $1
    fi
}


printf '\nBREW installation/update\n'
if ! type brew > /dev/null; then
    printf "Brew not found... installing\n"
    /usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
else
    printf "Updating brew\n"
    brew update
fi


printf '\nPYTHON installation/update\n'
brew_install python

python_ver=$(python -c "import sys;print '%d.%d.%d' % sys.version_info[:3]")
python_loc=$(which python) 
printf "Your python version: $python_ver\n"

# check if python installation looks right
if [ "$python_ver" != "$PYTHON_TGT_VER" ]; then
    printf "python version incorrect. Should be $PYTHON_TGT_VER\n"
    err=1
fi

printf "Your python location: $python_loc\n"
if [ "$python_loc" != "$PYTHON_TGT_LOC" ]; then
    printf "python location incorrect. Should be $PYTHON_TGT_LOC\n"
    err=1
fi

if [ $err ]; then
    printf 'Make sure /usr/local/bin is the first item in $PATH\n'
    printf "Your PATH is currently: $PATH\n"
    exit
fi


printf '\nInstalling sdl2 components:\n'
brew_install sdl2
brew_install sdl2_image
brew_install sdl2_ttf
brew_install sdl2_mixer

printf '\nInstalling portaudio:\n'
brew_install portaudio

printf '\nInstalling fluid-synth:\n'
brew_install fluid-synth


# pip installations
printf '\nUpgrading pip:\n'
pip install pip --upgrade

printf '\nInstalling numpy:\n'
pip install numpy

printf '\nInstalling matplotlib:\n'
pip install matplotlib

printf '\nInstalling kivy:\n'
pip install pygame
pip install -I Cython==0.23
USE_OSX_FRAMEWORKS=0 
pip install kivy

printf '\nInstalling rtmidi_python:\n'
pip install rtmidi_python

printf '\nInstalling pyaudio:\n'
pip install --global-option=build_ext --global-option="-I/usr/local/include" --global-option="-L/usr/local/lib" pyaudio


# reload shell in case the above installations changed location of apps
printf '\n Reloading Shell\n'
exec bash --login
